NaMaster: nmt_workspace Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_workspace Struct Reference

Full-sky mode-coupling matrix. More...

`#include <namaster.h>`

## Data Fields
int | lmax
| Maximum multipole used. More...
int | lmax_fields
| Resolution of fields being correlated. More...
int | lmax_mask
| Mask resolution. More...
int | is_teb
| Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations? More...
int | ncls
| Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated. More...
nmt_curvedsky_info * | cs
| curved sky geometry information. More...
flouble * | beam_prod
| Product of field beams. More...
flouble * | pcl_masks
| Pseudo-CL of the masks. More...
flouble ** | coupling_matrix_unbinned
| Unbinned mode-coupling matrix. More...
nmt_binning_scheme * | bin
| Bandpowers defining the binning. More...
gsl_matrix * | coupling_matrix_binned
| GSL version of MCM (prepared for inversion) More...
gsl_permutation * | coupling_matrix_perm
| Complements `coupling_matrix_binned_gsl` for inversion. More...

## Detailed Description

Full-sky mode-coupling matrix.

Structure containing information about the mode-coupling matrix (MCM) for full-sky pseudo-CLs.

## Field Documentation

flouble* nmt_workspace::beam_prod

Product of field beams.

nmt_binning_scheme* nmt_workspace::bin

Bandpowers defining the binning.

gsl_matrix* nmt_workspace::coupling_matrix_binned

GSL version of MCM (prepared for inversion)

gsl_permutation* nmt_workspace::coupling_matrix_perm

Complements `coupling_matrix_binned_gsl` for inversion.

flouble** nmt_workspace::coupling_matrix_unbinned

Unbinned mode-coupling matrix.

nmt_curvedsky_info* nmt_workspace::cs

curved sky geometry information.

int nmt_workspace::is_teb

Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations?

int nmt_workspace::lmax

Maximum multipole used.

int nmt_workspace::lmax_fields

Resolution of fields being correlated.

int nmt_workspace::lmax_mask

Mask resolution.

int nmt_workspace::ncls

Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated.

flouble* nmt_workspace::pcl_masks

Pseudo-CL of the masks.

The documentation for this struct was generated from the following file:

- namaster.h